@@ -25,16 +25,17 @@
  * @title: GtkSourceCompletion
  * @short_description: Main Completion Object
  *
- * The completion system helps the user when he writes some text, such
- * as words, command names, functions, and suchlike. Proposals can be
- * shown, to complete the text the user is writing. Each proposal can
- * contain an additional piece of information, that is displayed when
- * the "Details" button is active.
+ * The completion system helps the user when he/she writes some text,
+ * such as words, command names, functions, and suchlike. Proposals can
+ * be shown, to complete the text the user is writing. Each proposal can
+ * contain an additional piece of information (for example
+ * documentation), that is displayed when the "Details" button is
+ * clicked.
  *
  * Proposals are created via a #GtkSourceCompletionProvider. There can
  * be for example a provider to complete words (see
  * #GtkSourceCompletionWords), another provider for the completion of
- * function's names, etc. To add a provider, call
+ * function names, etc. To add a provider, call
  * gtk_source_completion_add_provider().
  *
  * When the completion is activated, a #GtkSourceCompletionContext object is
@@ -61,7 +62,7 @@
  *
  * A #GtkSourceCompletionInfo window can also be used to display
  * calltips. When no proposals are available, it can be useful to
- * display extra information like a function's prototype (number of
+ * display extra information like a function prototype (number of
  * parameters, types of parameters, etc).
  *
  * Each #GtkSourceView object is associated with a #GtkSourceCompletion
@@ -70,7 +71,7 @@
  * #GtkSourceView::show-completion signal.
  *
  * A same #GtkSourceCompletionProvider object can be used for several
- * #GtkSourceCompletion.
+ * #GtkSourceCompletion's.
  *
  * # GtkSourceCompletion as GtkBuildable
  *
@@ -2027,7 +2028,7 @@ init_tree_view (GtkSourceCompletion *completion,
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell_renderer;
 	GtkStyleContext *style_context;
-	GdkRGBA background_color;
+	GdkRGBA* background_color = NULL;
 	GdkRGBA foreground_color;
 
 	completion->priv->tree_view_proposals = GTK_TREE_VIEW (gtk_builder_get_object (builder, "tree_view_proposals"));
@@ -2093,7 +2094,7 @@ init_tree_view (GtkSourceCompletion *completion,
 	gtk_style_context_restore (style_context);
 
 	g_object_set (cell_renderer,
-	              "cell-background-rgba", &background_color,
+	              "cell-background-rgba", background_color,
 	              NULL);
 
 	g_object_bind_property (completion, "show-icons",
@@ -2115,7 +2116,7 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
-	              "cell-background-rgba", &background_color,
+	              "cell-background-rgba", background_color,
 	              NULL);
 
 	/* Accelerators cell renderer */
@@ -2131,7 +2132,7 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
-	              "cell-background-rgba", &background_color,
+	              "cell-background-rgba", background_color,
 		      NULL);
 
 	gtk_tree_view_column_set_cell_data_func (column,
@@ -2145,6 +2146,8 @@ init_tree_view (GtkSourceCompletion *completion,
 				 G_CALLBACK (accelerators_notify_cb),
 				 column,
 				 0);
+
+	gdk_rgba_free (background_color);
 }
 
 static void
@@ -2753,7 +2756,7 @@ _gtk_source_completion_add_proposals (GtkSourceCompletion         *completion,
 }
 
 /**
- * gtk_source_completion_show:
+ * gtk_source_completion_start:
  * @completion: a #GtkSourceCompletion.
  * @providers: (element-type GtkSource.CompletionProvider) (nullable):
  * a list of #GtkSourceCompletionProvider, or %NULL.
@@ -2773,9 +2776,9 @@ _gtk_source_completion_add_proposals (GtkSourceCompletion         *completion,
  * Returns: %TRUE if it was possible to the show completion window.
  */
 gboolean
-gtk_source_completion_show (GtkSourceCompletion        *completion,
-                            GList                      *providers,
-                            GtkSourceCompletionContext *context)
+gtk_source_completion_start (GtkSourceCompletion        *completion,
+			     GList                      *providers,
+			     GtkSourceCompletionContext *context)
 {
 	GList *selected_providers;
 
@@ -2950,7 +2953,7 @@ gtk_source_completion_remove_provider (GtkSourceCompletion          *completion,
 		return FALSE;
 	}
 
-	completion->priv->providers = g_list_remove_link (completion->priv->providers, item);
+	completion->priv->providers = g_list_delete_link (completion->priv->providers, item);
 
 	g_object_unref (provider);
 
@@ -3028,7 +3031,7 @@ gtk_source_completion_get_view (GtkSourceCompletion *completion)
  *
  * Returns: (transfer floating): a new #GtkSourceCompletionContext.
  * The reference being returned is a 'floating' reference,
- * so if you invoke gtk_source_completion_show() with this context
+ * so if you invoke gtk_source_completion_start() with this context
  * you don't need to unref it.
  */
 GtkSourceCompletionContext *
