@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcefilesaver.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2005-2007 - Paolo Borelli and Paolo Maggi
@@ -26,13 +26,13 @@
 #endif
 
 #include "gtksourcefilesaver.h"
+#include <glib/gi18n-lib.h>
 #include "gtksourcefile.h"
 #include "gtksourcebufferinputstream.h"
 #include "gtksourceencoding.h"
 #include "gtksourcebuffer.h"
 #include "gtksourcebuffer-private.h"
-#include "gtksourceview-enumtypes.h"
-#include "gtksourceview-i18n.h"
+#include "gtksource-enumtypes.h"
 
 /**
  * SECTION:filesaver
@@ -46,6 +46,12 @@
  * A file saver should be used only for one save operation, including errors
  * handling. If an error occurs, you can reconfigure the saver and relaunch the
  * operation with gtk_source_file_saver_save_async().
+ *
+ * <warning>
+ * This class is no longer maintained, patches are not accepted. There is a
+ * better implementation in the
+ * <ulink url="https://wiki.gnome.org/Projects/Tepl">Tepl</ulink> library.
+ * </warning>
  */
 
 /* The code has been written initially in gedit (GeditDocumentSaver).
