@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtksourcemarkattributes.c
+ *
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2010 - Jesse van den Kieboom
@@ -25,7 +25,6 @@
 
 #include "gtksourcemarkattributes.h"
 #include "gtksourcemark.h"
-#include "gtksourceview-i18n.h"
 #include "gtksourcepixbufhelper.h"
 
 /**
